.. include:: ../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   readme
   install
   falsehoods
   bitbar
   meta_package_manager
   development
   changelog
   todolist
   history
   license


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
